FakeCommandCall class

One recorded FakeCommandExec.run call.

Constructors

FakeCommandCall({required String command, required List<String> arguments, String? workingDirectory, Duration? timeout})
Creates a recorded invocation.
const

Properties

arguments → List<String>
Arguments passed to command.
final
command → String
Executable that was requested.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout → Duration?
Timeout passed to CommandExec.run, if any.
final
workingDirectory → String?
Working directory passed to CommandExec.run, if any.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited